ColorModel class abstract

The base color model class.

Implemented types
Available extensions
Annotations

Constructors

ColorModel()

Properties

a → double
The alpha channel of this color.
finalinherited
alpha → int
The alpha value of this color.
finalinherited
b → double
The blue channel of this color.
finalinherited
blue → int
The blue channel of this color in an 8 bit value.
no setterinherited
chroma → double
Calculates a value representing this color's lightness on a linear scale.
no setterinherited
colorSpace → ColorSpace
The color space of this color.
finalinherited
g → double
The green channel of this color.
finalinherited
green → int
The green channel of this color in an 8 bit value.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hex → String
Returns this as a hexidecimal string.
no setterinherited
hue → num
Gets the hue value of this color.
no setterinherited
inverted → ColorModel
Inverts the values of this ColorModel, excluding alpha, in its own color space.
no setter
isBlack → bool
Returns true if this color is pure black.
no setterinherited
isMonochromatic → bool
Returns true if this color is monochromatic.
no setterinherited
isWhite → bool
Returns true if this color is pure white.
no setterinherited
opacity → double
The alpha value as a double normalized to a 0.0 to 1.0 range.
no setterinherited
opposite → ColorModel
Returns the color with the hue opposite of this colors'.
no setter
r → double
The red channel of this color.
finalinherited
red → int
The red channel of this color in an 8 bit value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation → num
The saturation value of this color. Color spaces without a saturation value will be converted to HSL to retrieve the value.
no setterinherited
value → int
A 32 bit value representing this color.
no setterinherited

Methods

castTo(ColorModel other) → ColorModel
Converts this color to other's color space.
inherited
computeLuminance() → double
Returns a brightness value between 0 for darkest and 1 for lightest.
inherited
convert(ColorModel other) → ColorModel
Converts other to this color's color space.
cooler(num amount, {bool relative}) → ColorModel
Adjusts the hue of this color by amount towards 270 degrees, capping the value at 270.
copyWith({int? alpha}) → ColorModel
Returns a copy of this color modified with the provided values.
distanceTo(ColorModel color) → double
Returns the distance between this color's hue and color's hue in degrees.
inherited
equals(ColorModel color) → bool
Compares colors in the RGB color space.
inherited
interpolate(ColorModel end, double step) → ColorModel
Interpolates to step between this and end.
interpolate(Color end, double step) → Color

Available on Color, provided by the LerpToColor extension

Interpolates to the defined step between this color and end.
lerpTo(ColorModel color, int steps, {ColorSpace? colorSpace, bool excludeOriginalColors}) → List<ColorModel>
Returns the interpolated steps between this color and color.
lerpTo(Color color, int steps, {ColorSpace? colorSpace, bool excludeOriginalColors = false}) → List<Color>

Available on Color, provided by the LerpToColor extension

Returns the interpolated steps between this color and color.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateHue(num amount) → ColorModel
Rotates the hue of this color by amount in degrees.
rotateHueRad(double amount) → ColorModel
Rotates the hue of this color by amount in radians.
toARGB32() → int
Returns a 32-bit value representing this color.
inherited
toCmykColor() → CmykColor

Available on Color, provided by the ToColorModel extension

Returns this color as a CmykColor.
toCmykColor() → CmykColor
Converts this to the CMYK color space.
toColor() → Color

Available on ColorModel, provided by the ToColor extension

Returns this as a Color, converting the color to RGB if necessary.
toColorModel() → ColorModel

Available on Color, provided by the ToColorModel extension

If this is a ColorModel, return this, otherwise construct a new RgbColor from this Color.
toHsbColor() → HsbColor
Converts this to the HSB color space.
toHsbColor() → HsbColor

Available on Color, provided by the ToColorModel extension

Returns this color as a HsbColor.
toHsiColor() → HsiColor

Available on Color, provided by the ToColorModel extension

Returns this color as a HsiColor.
toHsiColor() → HsiColor
Converts this to the HSI color space.
toHslColor() → HslColor
Converts this to the HSL color space.
toHslColor() → HslColor

Available on Color, provided by the ToColorModel extension

Returns this color as a HslColor.
toHspColor() → HspColor
Converts this to the HSP color space.
toHspColor() → HspColor

Available on Color, provided by the ToColorModel extension

Returns this color as a HspColor.
toLabColor() → LabColor

Available on Color, provided by the ToColorModel extension

Returns this color as a LabColor.
toLabColor() → LabColor
Converts this to the LAB color space.
toList() → List<num>
Returns the values of the color model in the same order as their characters in their color space's abbreviation.
inherited
toListWithAlpha() → List<num>
Returns the values of the color model in the same order as their characters in their color space's abbreviation plus the alpha value.
inherited
toOklabColor() → OklabColor

Available on Color, provided by the ToColorModel extension

Returns this color as an OklabColor.
toOklabColor() → OklabColor
Converts this to the Oklab color space.
toRgbColor() → RgbColor

Available on Color, provided by the ToColorModel extension

Returns this color as a RgbColor.
toRgbColor() → RgbColor
Converts this to the RGB color space.
toString() → String
A string representation of this object.
inherited
toXyzColor() → XyzColor
Converts this to the XYZ color space.
toXyzColor() → XyzColor

Available on Color, provided by the ToColorModel extension

Returns this color as a XyzColor.
warmer(num amount, {bool relative}) → ColorModel
Adjusts the hue of this color by amount towards 90 degrees, capping the value at 90.
withAlpha(int alpha) → ColorModel
Returns this ColorModel with the provided alpha value.
withBlue(int b) → Color
Returns a new color that matches this color with the blue channel replaced with b (which ranges from 0 to 255).
inherited
withChroma(double chroma) → ColorModel
Converts this color to the Oklab color space, calculates and applies a new lightness value from the proivded chroma value, and converts it back to the original color space.
withGreen(int g) → Color
Returns a new color that matches this color with the green channel replaced with g (which ranges from 0 to 255).
inherited
withHue(num hue) → ColorModel
Returns this ColorModel with the provided hue value.
withOpacity(double opacity) → ColorModel
Returns this ColorModel with the provided opacity value.
withRed(int r) → Color
Returns a new color that matches this color with the red channel replaced with r (which ranges from 0 to 255).
inherited
withValues(List<num> values) → ColorModel
Returns a color in this color's color space with the values provided.

Operators

operator ==(Object other) → bool
The equality operator.
inherited