ColorSpace enum

An enumeration representing the color spaces defined in this package.

Inheritance
Available extensions

Values

cmyk → const ColorSpace
hsb → const ColorSpace
hsi → const ColorSpace
hsl → const ColorSpace
hsp → const ColorSpace
lab → const ColorSpace
oklab → const ColorSpace
rgb → const ColorSpace
xyz → const ColorSpace

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on ColorSpace, provided by the ConvertToColorSpace extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(ColorModel color) → ColorModel

Available on ColorSpace, provided by the ConvertToColorSpace extension

Converts color to this color space.
fromColor(Color color) → ColorModel

Available on ColorSpace, provided by the ConvertToColorSpace extension

Converts color to a ColorModel in this color space.
fromList(List<num> values) → ColorModel

Available on ColorSpace, provided by the ConvertToColorSpace extension

Returns a ColorModel in this color space from values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ColorSpace>
A constant List of the values in this enum, in order of their declaration.