LerpToColor extension

on

Methods

interpolate(Color end, double step) → Color

Available on Color, provided by the LerpToColor extension

Interpolates to the defined step between this color and end.
lerpTo(Color color, int steps, {ColorSpace? colorSpace, bool excludeOriginalColors = false}) → List<Color>

Available on Color, provided by the LerpToColor extension

Returns the interpolated steps between this color and color.